@@ -7,7 +7,7 @@ import { ReactNode } from 'react';
 import { render } from 'react-dom';
 
 import { Calendar } from '@/components/Calendar';
-import { Search } from '@/components/icons';
+import { Close, Menu, Search } from '@/components/icons';
 import { theme } from '@/theme';
 
 function MaterialUIProvider({ children }: { children: ReactNode }) {
@@ -318,6 +318,11 @@ function renderCalendars() {
   );
 }
 
+function fixSearchInput() {
+  const searchInput = document.querySelector('input[type=search]');
+  searchInput?.setAttribute('type', 'text');
+}
+
 function fixSearchContainer() {
   const oldSearchButton = document.querySelector<HTMLInputElement>(
     '#search-documentation ~ form > input[type=submit]',
@@ -427,6 +432,36 @@ function fixSearchResults() {
   }
 }
 
+function renderAppBarMenuButton() {
+  const menuButton = document.querySelector('.navbar-toggler');
+
+  if (menuButton) {
+    render(<Menu />, menuButton);
+
+    const observer = new MutationObserver((mutations) =>
+      mutations.forEach((mutation) => {
+        if (mutation.attributeName === 'class') {
+          if (menuButton.classList.contains('collapsed')) {
+            render(<Menu />, menuButton);
+          } else {
+            render(<Close />, menuButton);
+          }
+        }
+      }),
+    );
+
+    observer.observe(menuButton, {
+      attributes: true,
+    });
+  }
+}
+
+function addClassToCodeBlocksWithLineNumbers() {
+  Array.from(document.querySelectorAll('.highlight')).forEach(
+    (el) => el.querySelector('.linenos') && el.classList.add('line-numbers'),
+  );
+}
+
 function main() {
   highlightActivePageTocItem();
   fixCodeLinks();
@@ -435,7 +470,10 @@ function main() {
   addVersionIcons();
   replaceSidebarIcons();
   renderCalendars();
+  renderAppBarMenuButton();
+  addClassToCodeBlocksWithLineNumbers();
   // Wrap in setTimeout so that it runs after sphinx search JS.
+  setTimeout(fixSearchInput);
   setTimeout(fixSearchContainer);
   setTimeout(fixSearchText);
   setTimeout(fixSearchResults);
